



-- auctionmaster support

do
	local AuctionMaster = vendor			-- the actual "AuctionMaster" global table is called "vendor"



	local auctionMasterSupport = {}

	auctionMasterSupport.isNeutral = false

	function auctionMasterSupport:ScanSnapshotUpdated(snapshot, neutral)
		LSW:FlushPriceData()
	end

	local function GetItemLink(itemID)
		if itemID then
			local _,link = GetItemInfo(itemID)
			return link
		end

		return nil
	end


	local function AuctionPrice(itemID)
		local link = GetItemLink(itemID)

		if not link then
			return nil
		end

		local _, sellPrice = AuctionMaster.Statistic:GetAuctionInfo(link, auctionMasterSupport.isNeutral)

		return sellPrice
	end



	local function AuctionPriceCurrent(itemID)
		local link = GetItemLink(itemID)

		if not link then
			return nil
		end

		local result = AuctionMaster.Scanner:GetScanSet(auctionMasterSupport.isNeutral, link)

		local totalBuyout = 0
		local numItems = 0

		if (result and result:Size() > 0) then
			for i = 1, result:Size() do
				local itemLinkKey, time, timeLeft, count, minBid, minIncrement, buyout = result:Get(i)

				if buyout then
					numItems = numItems + count
					totalBuyout = totalBuyout + buyout
				end
			end
		end

		if numItems>0 then
			return floor(totalBuyout/numItems), numItems
		else
			return nil, 0
		end
	end


	local function AuctionPriceMinBuyout(itemID)
		local link = GetItemLink(itemID)

		if not link then
			return nil
		end

		local result = AuctionMaster.Scanner:GetScanSet(auctionMasterSupport.isNeutral, link)

		local minBuyout
		local numItems = 0

		if (result and result:Size() > 0) then
			for i = 1, result:Size() do
				local itemLinkKey, time, timeLeft, count, minBid, minIncrement, buyout = result:Get(i)

				if buyout then
					buyout = buyout / count

					numItems = numItems + count

					if (not minBuyout) or (minBuyout > buyout) then
						minBuyout = buyout
					end
				end
			end
		end

		return minBuyout, numItems
	end






	local function Init()
		local faction = UnitFactionGroup("player")
--		LSW:ChatMessage("LilSparky's Workshop adding AuctionMaster support")

		AuctionMaster.Scanner:AddScanSnapshotListener(auctionMasterSupport)

		local optionsMenu = LSW:RegisterMenu("AuctionMaster Options")
		optionsMenu:RegisterToggle("AuctionMaster: Neutral Data", auctionMasterSupport, "isNeutral")

		local optionsMenuTable = optionsMenu:GenerateMenuTable(function(button, opt)
			CloseDropDownMenus()
			LSW:FlushPriceData()
		end)


		LSW:RegisterAlgorithm("AuctionMaster Historical", AuctionPrice)
		LSW:RegisterAlgorithm("AuctionMaster Current", AuctionPriceCurrent)
		LSW:RegisterAlgorithm("AuctionMaster Min Buyout", AuctionPriceMinBuyout)


		return optionsMenuTable
	end


	local function Test(index)
		if IsAddOnLoaded("AuctionMaster") then
			return true
		end

		return false
	end

	LSW:RegisterPricingSupport("AuctionMaster", Test, Init)
end

